@@ -1,4 +1,4 @@
-// Copyright (C) 2017 Free Software Foundation, Inc.
+// Copyright (C) 2017-2018 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -16,7 +16,7 @@
 // <http://www.gnu.org/licenses/>.
 
 // { dg-options "-std=gnu++17" }
-// { dg-do compile { target c++1z } }
+// { dg-do compile { target c++17 } }
 
 #include <functional>
 
@@ -26,6 +26,6 @@ int f() noexcept { return 0; }
 auto b = std::bind(f);
 static_assert(std::is_same_v<decltype(b)::result_type, int>);
 
-struct X { long f() const noexcept { return 0L; } };
+struct X { long f() const & noexcept { return 0L; } };
 auto b2 = std::bind(&X::f, X{});
 static_assert(std::is_same_v<decltype(b2)::result_type, long>);
