@@ -1,6 +1,6 @@
 // 2001-08-23  Benjamin Kosnik  <bkoz@redhat.com>
 
-// Copyright (C) 2001-2015 Free Software Foundation, Inc.
+// Copyright (C) 2001-2018 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -27,8 +27,7 @@ class gnu_moneypunct_t: public std::moneypunct<char, true>
 { };
 
 void test03()
-{ 
-  bool test __attribute__((unused)) = true;
+{
   gnu_moneypunct_t facet01;
   VERIFY (facet01.intl == true);
 }
